////////////////////////////////////////////////////////////////////////////
// This is a sample program to override certain keyboard actions
// for a modeless dialog using OWL 2.0 and above.
//
// Written by George Cross, Borland C++ Tech Support
// February 1996
//
// Borland C++ 5.0, but is valid for OWL 2.x 
//
// This application displays a dialog an beeps if the user presses
// Escape or Enter.  The Enter key is overridden using the virtual
// PreProcessMsg function.  The Escape key is overridden using the
// Accelerator resource.  You may choose to use either technique
// for any key.
//
// Another method you can use is contained in the sample GETDLG.ZIP
// available on BBS and Compuserve and perhaps the FTP site.
//
// For modal dialog boxes, you can't assign accelerators, and you can't
// get at the main message loop (see Win API help on IsDialogMessage -
// it is only for modeless dialog boxes).  If you like, you can
// emulate a modal dialog box with a modeless one.  Borland has a TI
// and sample code doing this, "Catching Accelerators in a modal
// dialog in OWL 2.x and above."
//
////////////////////////////////////////////////////////////////////////////

#include <owl\pch.h>
#include <owl\static.h>
#include "dlgaccel.rh"
#include <bwcc.h>

////////////////////////////////////////////////////////////////////////////
// Class to administer the dialog clients of each MDIChild window
////////////////////////////////////////////////////////////////////////////
class TMyDialog : public TDialog {
private:
	TStatic* pStatic;
public:
	TMyDialog ():TDialog (NULL, DIALOG_1){   //TMyDialog constructor
	//
	//Load the Accelerator Table.
	//Notice that we cannot use LoadAcceleratorTable. I think this is
	//because TDialog.Attr, unlike TWindow.Attr, has no member
	//AccelTable.
        //
	  TWindow::Attr.AccelTable = TResId(ACCELERATORS_1);
	  pStatic = new TStatic (this, IDC_STATIC1);  //Extraneous control...
	}
	bool PreProcessMsg (MSG& msg);       //Handles the ENTER/RETURN key
	void EvCmEscape();                   //Beeps and shows a message
   void SetupWindow ();                      //Initializes the window element

DECLARE_RESPONSE_TABLE(TMyDialog);
};                                          //End class declaration TMyDialog


DEFINE_RESPONSE_TABLE1(TMyDialog,TDialog)   //Response table def'n
	EV_COMMAND(IDHELP,EvCmEscape),
	EV_COMMAND(CM_ESCAPE, EvCmEscape),  //F'n to call when ESC key pressed
   EV_WM_KEYDOWN,
END_RESPONSE_TABLE;


//SetupWindow - does some simple initialization of a static
//control in this dialog
void TMyDialog::SetupWindow (){     //Initializes the window element
  TDialog::SetupWindow();           //Call the base class function

  string c;                         //Just an extraneous
  for (int h=1;h<=9;h++){           //initialization of the
     for (int i=1;i<=10;i++){       //extraneous static control
        for (int j=1;j<=10;j++){
           c += "c";
        }
        c += " ";
     }
  }
  pStatic->SetText (c.c_str());
}                                   //End SetupWindow()


//EvCmEscape - Handles pressing of the Escape key.  Be sure the
//Accelerator assigned to the Escape key does not have an ID of IDCANCEL.
//If it does, when the user clicks on Close on the dialog box, only this
//function will be called and the dialog box will not close.
//(try it and you'll see what happens.)
//
void TMyDialog::EvCmEscape(){
	MessageBeep(-1);MessageBox("Thanks for using Borland C++ !!");
}                                           //End EvCmEscape ()


//PreProcessMsg - Like the API function IsDialogMessage, this function
//is called for all messages which pass through the dialog.
//
bool TMyDialog::PreProcessMsg (MSG& msg){   //Handles the Enter key
	if (msg.message == WM_KEYDOWN &&    //If the Enter key is pressed
		 msg.wParam == VK_RETURN){
      EvCmEscape();                         //Call the function to beep
		return TRUE;                //and forbid closing
                                            //of the dialog
	}
	return TDialog::PreProcessMsg(msg); //Otherwise handle the message
}                                           //as would be normal
														  //End PreProcessMsg ()


////////////////////////////////////////////////////////////////////////////
// Class to administer the application class
////////////////////////////////////////////////////////////////////////////
class TComboDrpApplication : public TApplication {
public:
	TComboDrpApplication () : TApplication () {};
	void InitMainWindow();
};

// --------------------------------------------------------------- //
// InitMainWindow                                                  //
// --------------------------------------------------------------- //
void TComboDrpApplication::InitMainWindow()
{
  EnableBWCC();                     //Borland custom controls
  SetMainWindow(new TFrameWindow(NULL, NULL, new TMyDialog, TRUE));
}

// --------------------------------------------------------------- //
// OwlMain                                                         //
// --------------------------------------------------------------- //
int OwlMain(int /*argc*/, char* /*argv*/ [])
{
  TComboDrpApplication app;
  return app.Run();
}
